@@ -1,5 +1,5 @@
 (function (window) {
-    var settings = {{ jssettings|safe }}; 
+    var settings = JSON.parse('{{ jssettings|escapejs }}'); 
     S = function () { }
     S.get = function (key) { return settings[key]; }
     S.set = function (key, val) { return settings[key] = val; }
